@@ -482,14 +482,14 @@ gdm_display_dispose (GdmDisplay *d)
 
     if (d->type == TYPE_XDMCP_PROXY) {
 	    if (d->parent_auth_file != NULL) {
-		    VE_IGNORE_EINTR (unlink (d->parent_auth_file));
+		    VE_IGNORE_EINTR (g_unlink (d->parent_auth_file));
 	    }
 	    g_free (d->parent_auth_file);
 	    d->parent_auth_file = NULL;
     }
 
     if (d->parent_temp_auth_file != NULL) {
-	    VE_IGNORE_EINTR (unlink (d->parent_temp_auth_file));
+	    VE_IGNORE_EINTR (g_unlink (d->parent_temp_auth_file));
     }
     g_free (d->parent_temp_auth_file);
     d->parent_temp_auth_file = NULL;
