@@ -69,9 +69,7 @@ print_cant_auth_errbox (void)
 		    "case.");
 	if (is_capslock) {
 		msg = g_strconcat (basemsg, "  ",
-				   _("Please make sure the "
-				     "Caps Lock key is not "
-				     "enabled."),
+				   _("Caps Lock is on."),
 				   NULL);
 	} else {
 		msg = g_strdup (basemsg);
