@@ -312,7 +312,7 @@ solaris_xserver_cred (char *login, GdmDisplay *d, struct passwd *pwent)
 	if (!d->attached)
 	    return;
 
-	if (access (pwent->pw_dir, F_OK) != 0) {
+	if (g_access (pwent->pw_dir, F_OK) != 0) {
 	    gdm_debug ("solaris_xserver_cred: no HOME dir access\n");
 	    return;
 	}
@@ -328,7 +328,7 @@ solaris_xserver_cred (char *login, GdmDisplay *d, struct passwd *pwent)
 
         sprintf (pipe, "%s/%d", SDTLOGIN_DIR, displayNumber);
 
-        if ( stat (SDTLOGIN_DIR, &statbuf) == 0) {
+        if (g_stat (SDTLOGIN_DIR, &statbuf) == 0) {
 	    if (! statbuf.st_mode & S_IFDIR) {
 		gdm_debug ("solaris_xserver_cred: %s is not a directory\n",
 		       SDTLOGIN_DIR);
@@ -341,7 +341,7 @@ solaris_xserver_cred (char *login, GdmDisplay *d, struct passwd *pwent)
 	}
 
 	fd = open (pipe, O_RDWR);
-	unlink (pipe);
+	g_unlink (pipe);
 
 	if (fd < 0) {
             gdm_debug ("solaris_xserver_cred: could not open %s\n", pipe);
@@ -1126,9 +1126,7 @@ authenticate_again:
 		    }
 		    if (is_capslock) {
 			    msg = g_strconcat (basemsg, "  ",
-					       _("Please make sure the "
-						 "Caps Lock key is not "
-						 "enabled."),
+					       _("Caps Lock is on."),
 					       NULL);
 		    } else {
 			    msg = g_strdup (basemsg);
@@ -1518,9 +1516,9 @@ gdm_verify_check (void)
 
         if (gdm_get_value_bool (GDM_KEY_CONSOLE_NOTIFY))
 			gdm_text_message_dialog
-				(C_(N_("Can't find PAM configuration for gdm.")));
+				(C_(N_("Can't find PAM configuration for GDM.")));
 		gdm_fail ("gdm_verify_check: %s",
-			  _("Can't find PAM configuration for gdm."));
+			  _("Can't find PAM configuration for GDM."));
 	}
 
 	if (ph != NULL)
