@@ -17,7 +17,7 @@
  */
 
 #include <config.h>
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 #include <syslog.h>
 #include <pwd.h>
 #include <shadow.h>
@@ -70,9 +70,7 @@ print_cant_auth_errbox (void)
 		    "case.");
 	if (is_capslock) {
 		msg = g_strconcat (basemsg, "  ",
-				   _("Please make sure the "
-				     "Caps Lock key is not "
-				     "enabled."),
+				   _("Caps Lock is on."),
 				   NULL);
 	} else {
 		msg = g_strdup (basemsg);
