@@ -42,6 +42,7 @@
 #include "gdmconfig.h"
 
 static gboolean debug = FALSE;
+static int num_cmds   = 0;
 
 static char *
 do_command (int fd, const char *command, gboolean get_response)
@@ -68,6 +69,10 @@ do_command (int fd, const char *command, gboolean get_response)
 #endif
 	g_free (cstr);
 
+	num_cmds++;
+	if (debug)
+		g_print ("Incrementing num_cmds to %d\n", num_cmds);
+
 	if (ret < 0)
 		return NULL;
 
@@ -85,6 +90,12 @@ do_command (int fd, const char *command, gboolean get_response)
 
 	cstr = str->str;
 	g_string_free (str, FALSE);
+
+	if (strcmp (ve_sure_string (cstr), "ERROR 200 Too many messages") == 0) { 
+		g_free (cstr);
+		return NULL;
+	}
+
 	return cstr;
 }
 
@@ -114,6 +125,13 @@ gdmcomm_call_gdm (const char *command, const char * auth_cookie, const char *min
 	static int fd = 0;
 	char *ret;
 
+	if (num_cmds == (GDM_SUP_MAX_CONNECTIONS)) {
+	   do_command (fd, GDM_SUP_CLOSE, FALSE);
+	   VE_IGNORE_EINTR (close (fd));
+	   fd       = 0;
+	   num_cmds = 0;
+	}
+
 	if (tries <= 0)
 		return NULL;
 
@@ -148,9 +166,6 @@ gdmcomm_call_gdm (const char *command, const char * auth_cookie, const char *min
 		}
 		if ( ! version_ok_p (&ret[4], min_version)) {
 			g_free (ret);
-/*
-			do_command (fd, GDM_SUP_CLOSE, FALSE);
-*/
 			VE_IGNORE_EINTR (close (fd));
 			fd = 0;
 			return NULL;
@@ -171,11 +186,7 @@ gdmcomm_call_gdm (const char *command, const char * auth_cookie, const char *min
 						 min_version, tries - 1);
 		}
 		/* not auth'ed */
-		if (strcmp (ret, "OK") != 0) {
-/*
-			do_command (fd, GDM_SUP_CLOSE,
-				    FALSE);
-*/
+		if (strcmp (ve_sure_string (ret), "OK") != 0) {
 			VE_IGNORE_EINTR (close (fd));
 			fd = 0;
 			/* returns the error */
@@ -191,10 +202,6 @@ gdmcomm_call_gdm (const char *command, const char * auth_cookie, const char *min
 		return gdmcomm_call_gdm (command, auth_cookie, min_version, tries - 1);
 	}
 
-/*
-	do_command (fd, GDM_SUP_CLOSE, FALSE);
-*/
-
 	return ret;
 }
 
@@ -368,7 +375,7 @@ gdmcomm_get_auth_cookie (void)
 		ret = gdmcomm_call_gdm (cmd, NULL /* auth cookie */, "2.2.4.0", 5);
 		g_free (cmd);
 		if (ret != NULL &&
-		    strcmp (ret, "OK") == 0) {
+		    strcmp (ve_sure_string (ret), "OK") == 0) {
 			g_free (ret);
 			cookie = g_strdup (buffer);
 			break;
@@ -430,10 +437,10 @@ gdmcomm_check (gboolean show_dialog)
 		return FALSE;
 	}
 
-	VE_IGNORE_EINTR (statret = stat (GDM_SUP_SOCKET, &s));
+	VE_IGNORE_EINTR (statret = g_stat (GDM_SUP_SOCKET, &s));
 	if (statret < 0 ||
 	    s.st_uid != 0 ||
-	    access (GDM_SUP_SOCKET, R_OK|W_OK) != 0) {
+	    g_access (GDM_SUP_SOCKET, R_OK|W_OK) != 0) {
 		if (show_dialog) {
 			dialog = ve_hig_dialog_new
 				(NULL /* parent */,
@@ -459,10 +466,10 @@ gdmcomm_get_error_message (const char *ret, gboolean use_xnest)
 {
 	/* These need a bit more refinement */
 	if (ret == NULL) {
-		return _("Cannot communicate with gdm. Perhaps "
+		return _("Cannot communicate with GDM. Perhaps "
 			 "you have an old version running.");
 	} else if (strncmp (ret, "ERROR 0 ", strlen ("ERROR 0 ")) == 0) {
-		return _("Cannot communicate with gdm. Perhaps "
+		return _("Cannot communicate with GDM. Perhaps "
 			 "you have an old version running.");
 	} else if (strncmp (ret, "ERROR 1 ", strlen ("ERROR 1 ")) == 0) {
 		return _("The allowed limit of flexible X servers reached.");
@@ -480,7 +487,7 @@ gdmcomm_get_error_message (const char *ret, gboolean use_xnest)
 	} else if (strncmp (ret, "ERROR 6 ", strlen ("ERROR 6 ")) == 0) {
 		if (use_xnest)
 			return _("The nested X server (Xnest) is not "
-				 "available, or gdm is badly configured.\n"
+				 "available, or GDM is badly configured.\n"
 				 "Please install the Xnest package in "
 				 "order to use the nested login.");
 		else
@@ -500,7 +507,7 @@ gdmcomm_get_error_message (const char *ret, gboolean use_xnest)
 			 "for this operation.  Perhaps your .Xauthority "
 			 "file is not set up correctly.");
 	} else if (strncmp (ret, "ERROR 200 ", strlen ("ERROR 200 ")) == 0) {
-		return _("Too many messages were sent to gdm and it hung up"
+		return _("Too many messages were sent to GDM and it hung up "
 			 "on us.");
 	} else {
 		return _("Unknown error occurred.");
