@@ -57,7 +57,7 @@ gchar*	gdm_common_get_config_file	(void);
 gboolean gdm_common_select_time_format	(void);
 void	gdm_common_setup_background_color (gchar *bg_color);
 gchar*	gdm_common_get_welcomemsg	(void);
-void	gdm_common_post_display_launch  (void);
+void	gdm_common_pre_fetch_launch     (void);
 gchar*  gdm_common_expand_text          (const gchar *text);
 gchar*  gdm_common_get_clock            (struct tm **the_tm);
 
