@@ -1083,7 +1083,7 @@ parse_stock (xmlNodePtr node,
       else if (g_ascii_strcasecmp ((char *) prop, "reboot") == 0)
         {
 	  g_free (*translated_text);
-	  *translated_text = g_strdup (_("_Reboot"));
+	  *translated_text = g_strdup (_("_Restart"));
 	}
       else if (g_ascii_strcasecmp ((char *) prop, "chooser") == 0)
         {
@@ -1098,7 +1098,7 @@ parse_stock (xmlNodePtr node,
       else if (g_ascii_strcasecmp ((char *) prop, "caps-lock-warning") == 0)
         {
 	  g_free (*translated_text);
-	  *translated_text = g_strdup (_("You've got capslock on!"));
+	  *translated_text = g_strdup (_("Caps Lock is on."));
 	}
       else if (g_ascii_strcasecmp ((char *) prop, "timed-label") == 0)
         {
